Structs
- Dot
- Represents the Dot Product similarity metric.
- L2
- Represents the L2 (Euclidean) squared distance metric.
Traits
- Distance
Metric - A trait defining a specific distance metric for comparing vectors.
- Indexable
- A trait representing a dataset that can be accessed into vector chunks.
- Vector
Type
Functions
- knn
- Performs a K-Nearest Neighbors (KNN) search in parallel.